@@ -79,6 +79,7 @@ static CProfile EmptyProfile;
 CProfileManager::CProfileManager() :
     m_usingLoginScreen(false),
     m_profileLoadedForLogin(false),
+    m_previousProfileLoadedForLogin(false),
     m_autoLoginProfile(-1),
     m_lastUsedProfile(0),
     m_currentProfile(0),
@@ -189,6 +190,15 @@ bool CProfileManager::Load()
       ret = false;
     }
   }
+  if (!ret)
+  {
+    CLog::Log(LOGERROR,
+              "Failed to load profile - might be corrupted - falling back to master profile");
+    m_profiles.clear();
+    CFile::Delete(file);
+
+    ret = true;
+  }
 
   if (m_profiles.empty())
   { // add the master user
@@ -245,6 +255,7 @@ void CProfileManager::Clear()
   CSingleLock lock(m_critical);
   m_usingLoginScreen = false;
   m_profileLoadedForLogin = false;
+  m_previousProfileLoadedForLogin = false;
   m_lastUsedProfile = 0;
   m_nextProfileId = 0;
   SetCurrentProfileId(0);
@@ -280,7 +291,6 @@ bool CProfileManager::LoadProfile(unsigned int index)
       pWindow->ResetControlStates();
 
     UpdateCurrentProfileDate();
-    Save();
     FinalizeLoadProfile();
 
     return true;
@@ -297,7 +307,7 @@ bool CProfileManager::LoadProfile(unsigned int index)
 
   // save any settings of the currently used skin but only if the (master)
   // profile hasn't just been loaded as a temporary profile for login
-  if (g_SkinInfo != nullptr && !m_profileLoadedForLogin)
+  if (g_SkinInfo != nullptr && !m_previousProfileLoadedForLogin)
     g_SkinInfo->SaveSettings();
 
   // @todo: why is m_settings not used here?
@@ -307,7 +317,7 @@ bool CProfileManager::LoadProfile(unsigned int index)
   settings->Unload();
 
   SetCurrentProfileId(index);
-  m_profileLoadedForLogin = false;
+  m_previousProfileLoadedForLogin = false;
 
   // load the new settings
   if (!settings->Load())
@@ -360,9 +370,10 @@ bool CProfileManager::LoadProfile(unsigned int index)
   lock.Leave();
 
   UpdateCurrentProfileDate();
-  Save();
   FinalizeLoadProfile();
 
+  m_profileLoadedForLogin = false;
+
   return true;
 }
 
@@ -406,31 +417,29 @@ void CProfileManager::FinalizeLoadProfile()
   // Restart context menu manager
   contextMenuManager.Init();
 
-  // restart PVR services
-  pvrManager.Init();
+  // Restart PVR services if we are not just loading the master profile for the login screen
+  if (m_previousProfileLoadedForLogin || m_currentProfile != 0 || m_lastUsedProfile == 0)
+    pvrManager.Init();
 
   favouritesManager.ReInit(GetProfileUserDataFolder());
 
-  serviceAddons.Start();
-
-  g_application.UpdateLibraries();
+  // Start these operations only when a profile is loaded, not on the login screen
+  if (!m_profileLoadedForLogin || (m_profileLoadedForLogin && m_lastUsedProfile == 0))
+  {
+    serviceAddons.Start();
+    g_application.UpdateLibraries();
+  }
 
   stereoscopicsManager.Initialize();
 
   // Load initial window
   int firstWindow = g_SkinInfo->GetFirstWindow();
 
-  // the startup window is considered part of the initialization as it most likely switches to the final window
-  bool uiInitializationFinished = firstWindow != WINDOW_STARTUP_ANIM;
-
   CServiceBroker::GetGUI()->GetWindowManager().ChangeActiveWindow(firstWindow);
 
-  // if the user interfaces has been fully initialized let everyone know
-  if (uiInitializationFinished)
-  {
-    CGUIMessage msg(GUI_MSG_NOTIFY_ALL, 0, 0, GUI_MSG_UI_READY);
-    CServiceBroker::GetGUI()->GetWindowManager().SendThreadMessage(msg);
-  }
+  //the user interfaces has been fully initialized, let everyone know
+  CGUIMessage msg(GUI_MSG_NOTIFY_ALL, WINDOW_SETTINGS_PROFILES, 0, GUI_MSG_UI_READY);
+  CServiceBroker::GetGUI()->GetWindowManager().SendThreadMessage(msg);
 }
 
 void CProfileManager::LogOff()
@@ -445,6 +454,9 @@ void CProfileManager::LogOff()
   if (CVideoLibraryQueue::GetInstance().IsRunning())
     CVideoLibraryQueue::GetInstance().CancelAllJobs();
 
+  // Stop PVR services
+  CServiceBroker::GetPVRManager().Stop();
+
   networkManager.NetworkMessage(CNetwork::SERVICES_DOWN, 1);
 
   LoadMasterProfileForLogin();
@@ -576,19 +588,26 @@ int CProfileManager::GetProfileIndex(const std::string &name) const
 
 void CProfileManager::AddProfile(const CProfile &profile)
 {
-  CSingleLock lock(m_critical);
-  // data integrity check - covers off migration from old profiles.xml,
-  // incrementing of the m_nextIdProfile,and bad data coming in
-  m_nextProfileId = std::max(m_nextProfileId, profile.getId() + 1);
+  {
+    CSingleLock lock(m_critical);
+    // data integrity check - covers off migration from old profiles.xml,
+    // incrementing of the m_nextIdProfile,and bad data coming in
+    m_nextProfileId = std::max(m_nextProfileId, profile.getId() + 1);
 
-  m_profiles.push_back(profile);
+    m_profiles.push_back(profile);
+  }
+  Save();
 }
 
 void CProfileManager::UpdateCurrentProfileDate()
 {
   CSingleLock lock(m_critical);
   if (m_currentProfile < m_profiles.size())
+  {
     m_profiles[m_currentProfile].setDate();
+    CSingleExit exit(m_critical);
+    Save();
+  }
 }
 
 void CProfileManager::LoadMasterProfileForLogin()
@@ -598,10 +617,13 @@ void CProfileManager::LoadMasterProfileForLogin()
   m_lastUsedProfile = m_currentProfile;
   if (m_currentProfile != 0)
   {
+    // determines that the (master) profile has only been loaded for login
+    m_profileLoadedForLogin = true;
+
     LoadProfile(0);
 
     // remember that the (master) profile has only been loaded for login
-    m_profileLoadedForLogin = true;
+    m_previousProfileLoadedForLogin = true;
   }
 }
 
@@ -716,7 +738,10 @@ void CProfileManager::OnSettingAction(std::shared_ptr<const CSetting> setting)
 
 void CProfileManager::SetCurrentProfileId(unsigned int profileId)
 {
-  CSingleLock lock(m_critical);
-  m_currentProfile = profileId;
-  CSpecialProtocol::SetProfilePath(GetProfileUserDataFolder());
+  {
+    CSingleLock lock(m_critical);
+    m_currentProfile = profileId;
+    CSpecialProtocol::SetProfilePath(GetProfileUserDataFolder());
+  }
+  Save();
 }
